import { postHashtags, retrieveHashtagsFromGweet } from "@/components/trends";
import { uploadFiles } from "@/lib/uploadthing";

export const postGweet = async ({
  content,
  files,
  authorId,
  replyToGweetId,
  quoteGweetId,
}: {
  content: string;
  files: File[];
  authorId: string;
  replyToGweetId?: string | null;
  quoteGweetId?: string | null;
}) => {
  const gweet = {
    content,
    authorId,
    ...(replyToGweetId && { replyToGweetId }),
    ...(quoteGweetId && { quoteGweetId }),
  };

  try {
    const data = await fetch('/api/gweets', {
      method: 'POST',
      body: JSON.stringify(gweet)
    }).then((result) => result.json())

    if (files.length > 0) {
      const gweet_id = data.id;
      files.forEach(async (file) => {
        const [res] = await uploadFiles({ files: [file], endpoint: 'imageUploader' })

        const media = {
          ...(gweet_id && { gweet_id }),
          url: res.fileUrl,
          key: res.fileKey,
          type: "image",
        };

        await fetch('/api/media', {
          method: 'POST',
          body: JSON.stringify(media)
        })
      })
    }

    const hashtags = retrieveHashtagsFromGweet(content);
    if (hashtags) await postHashtags(hashtags);

    return data;
  } catch (error: any) {
    return error.response.data;
  }
};